==> escapework-manager-0.4.0-9a43a3.tar: src/views/pages/form.blade.php <==
@extends('manager::layouts.master')

@section('content')
    <div class="page-header">
        <div class="pull-left">
            <h2>Páginas</h2>
        </div><!-- .pull-left --> 

        <div class="pull-right">
            <a href="{{ route('manager.pages.index') }}" class="btn">Voltar</a>
        </div><!-- .pull-right -->

        <div class="clearfix"></div>
    </div><!-- .page-header --> 

    {{ Msg::getAll() }}

    <form action="{{ !$edit ? route('manager.pages.store') : route('manager.pages.update', $page->id) }}" method="post" id="form-page" class="form-horizontal">
        @if ($edit)
            <input type="hidden" name="_method" value="put" />
        @endif

        <fieldset>
            <div class="control-group">
                <label for="title" class="control-label">Título</label>

                <div class="controls">
                    <input type="text" name="title" id="title" class="input-xxlarge" value="{{ $page->title }}" required autofocus />
                </div><!-- .controls --> 
            </div><!-- .control-group --> 
        </fieldset>

        <fieldset>
            <legend>Ações da página</legend>
            
            <div class="control-group">
                <div class="controls">
                    <dl class="dl-horizontal" id="actions">
                        @foreach ($actions as $action)
                            <dt>
                                <input type="hidden" name="actionTitle[]" value="{{ $action->title }}" />
                                <input type="hidden" name="actionType[]" value="{{ $action->type }}" />

                                {{ $action->title }} (<small>{{ $action->type }}</small>) &nbsp; 
                            </dt>

                            <dd style="margin-bottom: 10px">
                                <a href="#" data-delete-action class="btn btn-small btn-danger">
                                    <i class="icon-trash icon-white"></i> excluir
                                </a>
                            </dd>
                        @endforeach
                    </ul>
                </div><!-- #acoes --> 
            </div><!-- .control-group --> 

            <div class="control-group">
                <div class="controls">
                    <div class="input-append">
                        <input type="text" class="input-medium" id="actionTitle" placeholder="Digite a ação..." /> 
                        <input type="text" class="input-medium" id="actionType" placeholder="Digite o tipo..." /> 

                        <a href="#" class="btn btn-success" id="js-add-action">Adicionar ação</a>
                    </div><!-- .input-append --> 

                    <span class="help-block">O tipo da ação será utilizado na validação das permissões, deve ser um nome sem espaços e/ou caracteres especiais.</span>
                </div><!-- .controls --> 
            </div><!-- .control-group --> 
        </fieldset>

        <div class="form-actions">
            <input type="submit" class="btn btn-primary" value="Salvar" /> 
            <a href="{{ route('manager.pages.index') }}" class="btn">Cancelar</a>
        </div><!-- .form-actions --> 
    </form>

    <script type="text/template" id="template-action">
        <dt>
            <input type="hidden" name="actionTitle[]" value="<%=title%>" /> 
            <input type="hidden" name="actionType[]" value="<%=type%>" /> 

            <%=title%> (<small><%=type%></small>) &nbsp; 
        </dt>

        <dd style="margin-bottom: 10px">
            <a href="#" data-delete-action class="btn btn-small btn-danger">
                <i class="icon-trash icon-white"></i> excluir
            </a>
        </dd>
    </script>
@stop

@section('scripts')
    @parent
    
    <script type="text/javascript" src="/packages/escapework/manager/assets/js/pages/form.js"></script>
@stop

==> escapework-manager-0.8.0-9a300b.tar: src/views/pages/form.blade.php <==
@extends(Config::get('manager::views.layouts.master'))

@section('content')
    <ul class="breadcrumb">
        <li><a href="{{ route('manager.home') }}">Home</a> <span class="divider">/</span></li>
        <li><a href="{{ route('manager.pages.index') }}">Páginas</a> <span class="divider">/</span></li>
        <li class="active">{{ $edit ? 'Editar' : 'Inserir' }}</li>
    </ul><!-- .breadcrumb -->

    <div class="page-header">
        <div class="pull-left">
            <h2>Páginas</h2>
        </div><!-- .pull-left -->

        <div class="pull-right">
            <a href="{{ route('manager.pages.index') }}" class="btn">Voltar</a>
        </div><!-- .pull-right -->

        <div class="clearfix"></div>
    </div><!-- .page-header -->

    {{ Msg::getAll() }}

    <form action="{{ !$edit ? route('manager.pages.store') : route('manager.pages.update', $page->id) }}" method="post" id="form-page" class="form-horizontal">
        @if ($edit)
            <input type="hidden" name="_method" value="put" />
        @endif

        <fieldset>
            <div class="control-group">
                <label for="title" class="control-label">Título</label>

                <div class="controls">
                    <input type="text" name="title" id="title" class="input-xxlarge" value="{{ $page->title }}" required autofocus />
                </div><!-- .controls -->
            </div><!-- .control-group -->
        </fieldset>

        <fieldset>
            <legend>Ações da página</legend>

            <div class="control-group">
                <div class="controls">
                    <dl class="dl-horizontal" id="actions">
                        @foreach ($actions as $action)
                            <dt>
                                <input type="hidden" name="actionTitle[]" value="{{ $action->title }}" />
                                <input type="hidden" name="actionType[]" value="{{ $action->type }}" />

                                {{ $action->title }} (<small>{{ $action->type }}</small>) &nbsp;
                            </dt>

                            <dd style="margin-bottom: 10px">
                                <a href="#" data-delete-action class="btn btn-small btn-danger">
                                    <i class="icon-trash icon-white"></i> excluir
                                </a>
                            </dd>
                        @endforeach
                    </ul>
                </div><!-- #acoes -->
            </div><!-- .control-group -->

            <div class="control-group">
                <div class="controls">
                    <div class="input-append">
                        <input type="text" class="input-medium" id="actionTitle" placeholder="Digite a ação..." />
                        <input type="text" class="input-medium" id="actionType" placeholder="Digite o tipo..." />

                        <a href="#" class="btn btn-success" id="js-add-action">Adicionar ação</a>
                    </div><!-- .input-append -->

                    <span class="help-block">O tipo da ação será utilizado na validação das permissões, deve ser um nome sem espaços e/ou caracteres especiais.</span>
                </div><!-- .controls -->
            </div><!-- .control-group -->
        </fieldset>

        <div class="form-actions">
            <input type="submit" class="btn btn-primary js-btn-submit" value="Salvar" data-loading-text="Carregando..." />
            <a href="{{ route('manager.pages.index') }}" class="btn">Cancelar</a>
        </div><!-- .form-actions -->
    </form>

    <script type="text/template" id="template-action">
        <dt>
            <input type="hidden" name="actionTitle[]" value="<%=title%>" />
            <input type="hidden" name="actionType[]" value="<%=type%>" />

            <%=title%> (<small><%=type%></small>) &nbsp;
        </dt>

        <dd style="margin-bottom: 10px">
            <a href="#" data-delete-action class="btn btn-small btn-danger">
                <i class="icon-trash icon-white"></i> excluir
            </a>
        </dd>
    </script>
@stop

@section('scripts')
    @parent

    <script type="text/javascript" src="{{ asset('packages/escapework/manager/assets/js/pages/form.js') }}"></script>
@stop
